/******************************************************************************/
/*									GENERAL INFO			  				  */
/******************************************************************************/
/*

PROJECT 
	Paper: Is the Mediterranean the New Rio Grande?
	Authors: Gordon Hanson and Craig McIntosh

DO FILE
	Created: February 2016 by Craig McIntosh and Chen Liu
	Updated: 19 May 2016 by Julia Clark
	Inputs: unpop.dta, code.dta, DIOC2000.dta, DIOC2005.dta, DIOC2010.dta, 
			WDI15.dta, dist_cepii.dta, 2020-2100.dta, GPK15.dta
	Main outputs: output$date.dta, migration_JEP_data_$date.dta
	Intermediate files (stored in 'temp' folder): 
			pop_code.dta, 1916-1950.dta, year_pop.dta, 
			des_pop.dta, origin_pop.dta, base_pop.dta, 
			2000.dta, originslist2000.dta, deslist2000.dta, mi2000.dta,
			2005.dta, originslist2005.dta, deslist2005.dta, mi2005.dta,
			2010.dta, originslist2010.dta, deslist2010.dta, mi2010.dta,
			dest.dta, tem.dta, region-origin.dta, DIOC2000-2010.dta, DIOC-pop.dta, 
			GDP_origin.dta, GDP_des.dta, GDP_15origin.dta, GDP_15des.dta,
			dist.dta, DIOC-POP-GDP-DIST.dta, DIOC-POP-GDP-DIST_15.dta, 
			2016-2035.dta, origin_pop1956-2035, des_pop1956-2035, 
			pop2020-2050.dta, pop-dist.dta, IMF_gdp.dta, 
			gdp2020-2050origin.dta, gdp2020-2050des.dta, gdp15origin.dta,
			DIOC-POP-GDP-DIST_15.dta, pop-dist-gpd2020-2050]

*/

/******************************************************************************/
/*									SETUP					  				  */
/******************************************************************************/

	clear all
	set more off
	global date 160516
	global raw "~/Dropbox/Migration_JEP/Migration_JEP_replication/data_raw"
	global tmp "~/Dropbox/Migration_JEP/Migration_JEP_replication/data_clean/temp"
	global fin "~/Dropbox/Migration_JEP/Migration_JEP_replication/data_clean"
	
/******************************************************************************/
/*							DATA MERGE: UNPOP 2000-2010  			  	  	  */
/******************************************************************************/

	use "$raw/unpop.dta", clear
	merge m:1 country using "$raw/code.dta"

	save "$tmp/pop_code.dta", replace
	sort country year sex

********************************************************************************
**Generating Cohort birth when it is first observed, save the output as base_pop.dta
**Create base cohort pop 1936-1950
	keep country year age04 age59 age1014 age1519 age2024 age2529 age3034 iso sex
	keep if year==1950

	ren age04 age14
	reshape long age, i (country sex iso) j(cohort)

	gen birth="1916-1920" if cohort==3034
	replace birth="1921-1925" if cohort==2529
	replace birth="1926-1930" if cohort==2024
	replace birth="1931-1935" if cohort==1519
	replace birth="1936-1940" if cohort==1014
	replace birth="1941-1945" if cohort==59
	replace birth="1946-1950" if cohort==14
	drop cohort year
	ren age base_pop
	save "$tmp/1916-1950.dta", replace

**Create base cohort pop 1951-1995
	use "$tmp/pop_code.dta", clear
	sort country year sex
	keep country year age04 sex iso
	drop if year==1950

	gen birth="1951-1955" if year==1955
	replace birth="1956-1960" if year==1960
	replace birth="1961-1965" if year==1965
	replace birth="1966-1970" if year==1970
	replace birth="1971-1975" if year==1975
	replace birth="1976-1980" if year==1980
	replace birth="1981-1985" if year==1985
	replace birth="1986-1990" if year==1990
	replace birth="1991-1995" if year==1995
	drop if birth==""

	ren age04 base_pop

**appending with 1936-1950 cohort
	append using "$tmp/1916-1950.dta"
	sort country birth sex
	drop year

	gen c_birth="1916-1925" if birth=="1916-1920" | birth=="1921-1925"
	replace c_birth="1926-1935" if birth=="1926-1930" | birth=="1931-1935"
	replace c_birth="1936-1945" if birth=="1936-1940" | birth=="1941-1945"
	replace c_birth="1946-1955" if birth=="1946-1950" | birth=="1951-1955"
	replace c_birth="1956-1965" if birth=="1956-1960" | birth=="1961-1965"
	replace c_birth="1966-1975" if birth=="1966-1970" | birth=="1971-1975"
	replace c_birth="1976-1985" if birth=="1976-1980" | birth=="1981-1985"
	replace c_birth="1986-1995" if birth=="1986-1990" | birth=="1991-1995"

	collapse (firstnm)country  (rawsum)base_pop, by (iso c_birth sex)

	ren c_birth birth

	sort iso sex birth 
	gen base_pop_lag10=base_pop[_n-1] if  iso==iso[_n-1] & sex==sex[_n-1] 
	gen base_pop_lag20=base_pop_lag10[_n-1] if  iso==iso[_n-1] & sex==sex[_n-1] 
	drop if birth=="1916-1925" | birth=="1926-1935"
	save "$tmp/base_pop.dta", replace

********************************************************************************
**Generating pop cohort by country and sex at 2000, 2005 and 2010. Output saved as "year_pop.dta"

	use "$tmp/pop_code.dta", clear
	sort country year sex
	drop _m
	keep if year==2000 | year==2005 | year==2010

	gen pop3645= age5559+ age6064 if year==2000
	replace pop3645=age6064+age6569 if year==2005
	replace pop3645=age6569+age7074 if year==2010

	gen pop4655= age4549+ age5054 if year==2000
	replace pop4655=age5054+age5559 if year==2005
	replace pop4655=age5559+age6064 if year==2010

	gen pop5665= age3539+ age4044 if year==2000
	replace pop5665=age4044+age4549 if year==2005
	replace pop5665=age4549+age5054 if year==2010

	gen pop6675= age2529+ age3034 if year==2000
	replace pop6675=age3034+age3539 if year==2005
	replace pop6675=age3539+age4044 if year==2010

	gen pop7685= age1519+ age2024 if year==2000
	replace pop7685=age2024+age2529 if year==2005
	replace pop7685=age2529+age3034 if year==2010

	gen pop8695= age59+ age1014 if year==2000
	replace pop8695=age1014+age1519 if year==2005
	replace pop8695=age1519+age2024 if year==2010

	keep country year sex pop3645 pop4655 pop5665 pop6675 pop7685 pop8695 iso

	reshape long pop, i (country year sex iso) j(cohort)

	gen birth="1936-1945" if cohort==3645
	replace birth="1946-1955" if cohort==4655
	replace birth="1956-1965" if cohort==5665
	replace birth="1966-1975" if cohort==6675 
	replace birth="1976-1985" if cohort==7685 
	replace birth="1986-1995" if cohort==8695

	drop cohort
	save "$tmp/year_pop.dta", replace

**********************************************************************************************************************************************************************************************************
****Merge base_pop.dta with year_pop.dta. Extract create destination and origin population and save them as des_pop.dta and origin.dta, respectively. 

	merge m:1 country birth sex using "$tmp/base_pop"
	drop _m
	gen destination=0
	ren iso countrycode
	replace destination=1 if countrycode=="AUS" | countrycode=="AUT" | countrycode=="BEL" | countrycode=="CAN" | countrycode=="CHE" | countrycode=="CHL" | countrycode=="CSFR" | countrycode=="CSFR-SVK" | countrycode=="DEU" | countrycode=="DNK" | countrycode=="ESP" | countrycode=="FIN" | countrycode=="FRA" | countrycode=="FYUG-SVN" | countrycode=="GBR" | countrycode=="GRC" | countrycode=="HUN" | countrycode=="IRL" | countrycode=="ISL" | countrycode=="ISR" | countrycode=="ITA" | countrycode=="JPN" | countrycode=="LUX" | countrycode=="MEX" | countrycode=="NLD" | countrycode=="NOR" | countrycode=="NZL" | countrycode=="POL" | countrycode=="PRT" | countrycode=="SVK" | countrycode=="SWE" | countrycode=="TUR" | countrycode=="USA" | countrycode=="USSR-EST"
	drop if countrycode==""

	save "$tmp/pop.dta", replace

	keep if des==1
	drop country
	ren countrycode iso
	drop dest
	ren pop des_pop
	ren base_pop des_base_pop
	ren base_pop_lag10 des_base_pop_lag10
	ren base_pop_lag20 des_base_pop_lag20
	collapse (rawsum) des_pop (rawsum)des_base_pop (rawsum) des_base_pop_lag10 (rawsum)des_base_pop_lag20 , by ( iso year sex birth )

	save "$tmp/des_pop", replace

	use "$tmp/pop.dta",clear
	ren countrycode coub
	drop dest
	ren pop origin_pop
	ren base_pop origin_base_pop
	drop if coub==""
	ren base_pop_lag10 origin_base_pop_lag10
	ren base_pop_lag20 origin_base_pop_lag20
	collapse (rawsum)origin_pop (rawsum)origin_base_pop (rawsum)origin_base_pop_lag10 (rawsum)origin_base_pop_lag20 (firstnm)country, by ( coub year sex birth )

	save "$tmp/origin_pop", replace


**********************************************************************************************************************************************************************************************************

*** Simulate a table with all possible combinations of origin-destination-birth cohort-sex (I use expand command), then merge with the actual DIOC 2000 data.
*The output is saved as "mi2000.dta"
*NOTE1 DIOC has country Former Czechoslovakia, Czech Republic, and Slovak Republic. I include Czech Republic and Slovak Republic in the analysis to match world bank data. 
*NOTE2 I cluster Serbia and Montenegro as Former Yugoslavia, as information on serbia are not observed. 

	use "$raw/DIOC2000.dta", clear
	replace country="CSFR" if country=="CSFR-CZE" | country=="CSFR-SVK" | country=="CZE" | country=="SVK"
	replace coub="CSFR" if coub=="CSFR-CZE" | coub=="CSFR-SVK" | coub=="CZE" | coub=="SVK"
	replace country="FYUG-YUG" if country=="FYUG-MNE" | country=="FYUG-SRB" | country=="FYUG"
	replace coub="FYUG-YUG" if coub=="FYUG-MNE" | coub=="FYUG-SRB" | coub=="FYUG"
	replace coub="KOREA-SO" if coub=="KOREA-NS"
	replace country="KOREA-SO" if country=="KOREA-NS"

	drop edu_lfs edu_cen age_lfs fborn reg_oecd

	collapse (rawsum)number (first)reg_regions, by (country coub age_cen sex)
	drop if country==""
	save "$tmp/2000.dta", replace

	**Obtain origin country list and save it as originlist.dta
	collapse sex, by (coub)
	drop sex
	save "$tmp/originlist2000.dta", replace

	**Obtain Destination country list and save it as deslist.dta
	use "$tmp/2000.dta", replace
	collapse sex, by (country)
	* give it id code 
	drop sex
	gen o_id=_n
	save "$tmp/deslist2000.dta", replace

***********************************************************************************************************

	use "$tmp/originlist2000.dta", clear

	* merge originlist.dta with deslist.dta to form all possible origin-des pairs. # of destination=28
	expand 28
	sort coub
	by coub: gen o_id=_n
	merge m:1 o_id using "$tmp/deslist2000.dta"
	drop _m o_id

	* create age dimension
	expand 10
	sort coub country
	by coub country: gen age_cen=_n

	gen birth="1936-1945" if age_cen==9 | age_cen==10
	replace birth="1946-1955" if age_cen==7 | age_cen==8
	replace birth="1956-1965" if age_cen==5 | age_cen==6
	replace birth="1966-1975" if age_cen==3 | age_cen==4
	replace birth="1976-1985" if age_cen==1 | age_cen==2

	* create sex dimension
	expand 2 
	sort coub country age_cen
	by coub country age_cen: gen sex=_n

	**Merge the similated table with the actual DIOC data 2000
	merge 1:1 country coub age_cen sex using "$tmp/2000.dta"

	*** drop people whose age are missing or above 65 in 2000   
	tab age_cen if _m==2
	drop if _m==2


	drop _m 

	sort coub country birth sex
	drop if birth==""
	drop age_cen
	gen year=2000
	save "$tmp/mi2000.dta", replace

**********************************************************************************************************************************************************************************************************

**Replicating for DIOC2005. the output is saved as "mi2005.dta"
	use "$raw/DIOC2005.dta", clear
	set more off

	replace country="CSFR" if country=="CSFR-CZE" | country=="CSFR-SVK" | country=="CZE" | country=="SVK"
	replace coub="CSFR" if coub=="CSFR-CZE" | coub=="CSFR-SVK" | coub=="CZE" | coub=="SVK"
	replace country="FYUG-YUG" if country=="FYUG-MNE" | country=="FYUG-SRB" | country=="FYUG"
	replace coub="FYUG-YUG" if coub=="FYUG-MNE" | coub=="FYUG-SRB" | coub=="FYUG"
	replace coub="KOREA-SO" if coub=="KOREA-NS"
	replace country="KOREA-SO" if country=="KOREA-NS"

	drop fborn edu_lfs edu_cen age_lfs reg_oecd_2010 reg_oecd_2000 
	collapse (rawsum)number (first)reg_regions, by (country coub age_cen sex)
	drop if country==""
	save "$tmp/2005.dta", replace

**Obtain origin country list and save it as originlist.dta
	collapse sex, by (coub)
	drop sex
	save "$tmp/originlist2005.dta", replace

**Obtain Destination country list and save it as deslist.dta
	use "$tmp/2005.dta", replace
	collapse sex, by (country)
	* give it id code 
	drop sex
	gen o_id=_n
	save "$tmp/deslist2005.dta", replace

	use "$tmp/originlist2005.dta", clear

* merge originlist.dta with deslist.dta to form all possible origin-des pairs. # of destination=27
	expand 27
	sort coub
	by coub: gen o_id=_n
	merge m:1 o_id using "$tmp/deslist2005.dta"
	drop _m o_id

* create age dimension
	expand 10
	sort coub country
	by coub country: gen age_cen=_n
	replace age_cen=age_cen+1


	gen birth="1936-1945" if age_cen==11 | age_cen==10
	replace birth="1946-1955" if age_cen==9 | age_cen==8
	replace birth="1956-1965" if age_cen==7 | age_cen==6
	replace birth="1966-1975" if age_cen==5 | age_cen==4
	replace birth="1976-1985" if age_cen==3 | age_cen==2

* create sex dimension
	expand 2 
	sort coub country age_cen
	by coub country age_cen: gen sex=_n

**Merge the similated table with the actual DIOC data 2005
	merge 1:1 country coub age_cen sex using "$tmp/2005.dta"

*** drop people whose age are missing or above 69 or younger than 20 in 2005   
	tab age_cen if _m==2
	drop if _m==2
	drop _m 

	sort coub country birth sex
	drop if birth==""
	drop age_cen
	gen year=2005
	save "$tmp/mi2005.dta", replace

**********************************************************************************************************************************************************************************************************

**Replicating for DIOC2010. the output is saved as "mi2010.dta"

	use "$raw/DIOC2010.dta", clear

	replace country="CSFR" if country=="CSFR-CZE" | country=="CSFR-SVK" | country=="CZE" | country=="SVK"
	replace coub="CSFR" if coub=="CSFR-CZE" | coub=="CSFR-SVK" | coub=="CZE" | coub=="SVK"
	replace country="FYUG-YUG" if country=="FYUG-MNE" | country=="FYUG-SRB" | country=="FYUG"
	replace coub="FYUG-YUG" if coub=="FYUG-MNE" | coub=="FYUG-SRB" | coub=="FYUG"
	replace coub="KOREA-SO" if coub=="KOREA-NS"
	replace country="KOREA-SO" if country=="KOREA-NS"

	drop ordre fborn national nationality edu_lfs edu_detailed 

	collapse (rawsum)number (first)reg, by (country coub age sex)
	drop if country==""
	save "$tmp/2010.dta", replace

**Obtain origin country list and save it as originlist.dta
	collapse sex, by (coub)
	drop sex
	save "$tmp/originlist2010.dta", replace

**Obtain Destination country list and save it as deslist.dta
	use "$tmp/2010.dta", replace
	collapse sex, by (country)
	* give it id code 
	drop sex
	gen o_id=_n
	save "$tmp/deslist2010.dta", replace


	use "$tmp/originlist2010.dta", clear

* merge originlist.dta with deslist.dta to form all possible origin-des pairs. # of destination=33
	expand 33
	sort coub
	by coub: gen o_id=_n
	merge m:1 o_id using "$tmp/deslist2010.dta"
	drop _m o_id

* create age dimension
	expand 5
	sort coub country
	by coub country: gen age=_n

	gen birth="1946-1955" if age==5
	replace birth="1956-1965" if age==4
	replace birth="1966-1975" if age==3
	replace birth="1976-1985" if age==2
	replace birth="1986-1995" if age==1

* create sex dimension
	expand 2 
	sort coub country age
	by coub country age: gen sex=_n

**Merge the similated table with the actual DIOC data 2010
	merge 1:1 country coub age sex using "$tmp/2010.dta"

*** drop people whose age are missing or 0-14 or 65+ in 2010 
	tab age if _m==2
	drop if _m==2
	drop _m 

	sort coub country birth sex
	drop if birth==""
	drop age
	gen year=2010
	save "$tmp/mi2010.dta", replace

**********************************************************************************************************************************************************************************************************
**Appending mi2000 mi2005 and mi2010, and fill the missing observation for variable region 

	append using "$tmp/mi2000"
	append using "$tmp/mi2005"

	save "$tmp/tem.dta", replace

	collapse (firstnm)regionb, by (coub)
	ren regionb region
	save "$tmp/region-origin.dta", replace

	use "$tmp/tem.dta", clear

	merge m:1 coub using "$tmp/region-origin.dta"

	drop regionb reg_regions _m

	gen gender="male" if sex==1
	replace gender="female" if sex==2
	drop sex 
	ren gender sex

	**Collapse data by origin-des-birth-sex-year, avoid collapse missing data to zeros

	bysort coub country birth sex year (number) : gen miss = mi(number[1]) 
	collapse (sum)number (min)miss (firstnm)region, by(coub country birth sex year)
	replace number=. if miss==1

	drop miss 
	ren country iso
	save "$tmp/DIOC2000-2010.dta", replace

***********************************************************************************************************************************************************************************************************
**merge DIOC2000-2010 DATA WITH "origin_pop.dta" and "des_pop.dta"

	set more off
	merge m:1 iso birth sex year using "$tmp/des_pop.dta"
	list birth year iso if _m==2
	tab iso if _m==2
	drop _m

	merge m:1 coub birth sex year using "$tmp/origin_pop.dta"
	tab coub if _m==2

	drop if _m==2
	drop _m

	drop if coub=="OTH" | coub=="UNK"

** Find origin country which has missing obs on migration stock (Var number)

	gen tem_region=region 
	replace tem_region="" if number!=.

** Using Var actual to distinguish the actual observation from interpolated observation

	gen actual=0
	replace actual=1 if tem_region==""

** Computing the overall origin pop for each sex, birth cohort by region (among origins which has missing migration stock)

	sort coub tem_region birth sex
	by coub tem_region birth sex: egen total_region_pop=sum(origin_pop) if number==.

*Computing population fraction within region, by birth cohort and sex              
	
	gen fraction=origin_pop/total_region_pop

	gen x=number if coub==region
	sort iso region birth sex year
	by iso region birth sex year: egen total_emmi=mean(x)

**Interpolating immigration stock for missing pairs

	replace number=total_emmi * fraction if number==.

	replace actual=. if number==.

	ren coub iso_o
	ren iso iso_d

	drop total_region_pop fraction x total_emmi tem_region

	tab act
	drop if iso_o==""
	sort iso_o iso_d birth year sex

	save "$tmp/DIOC-pop.dta", replace


***********************************************************************************************************************************************************************************************************
***********************************************************************************************************************************************************************************************************

**Create GDP/K using WDI for 2000 2005 and 2010 for each origin, destination countries. 
*Save output as "GDP_origin.dta" and "GDP_des.dta", respectively. 
** Change the countrycode of WDI data to match DIOC country code

	use "$raw/WDI15.dta", clear
	replace countrycode="AND" if countryname=="Andorra"
	replace countrycode="USSR-ARM" if countryname=="Armenia"
	replace countrycode="USSR-AZE" if countryname=="Azerbaijan"
	replace countrycode="FYUG-BIH" if countryname=="Bosnia and Herzegovina"
	replace countrycode="USSR-BLR" if countryname=="Belarus"
	replace countrycode="USSR-EST" if countryname=="Estonia"
	replace countrycode="USSR-GEO" if countryname=="Georgia"
	replace countrycode="FYUG-HRV" if countryname=="Croatia"
	replace countrycode="USSR-KAZ" if countryname=="Kazakhstan"
	replace countrycode="USSR-KGZ" if countryname=="Kyrgyz Republic"
	replace countrycode="KOREA-SO" if countryname=="Korea, Rep."
	replace countrycode="KOREA-NO" if countryname=="Korea, Dem. Rep."
	replace countrycode="USSR-LTU" if countryname=="Lithuania"
	replace countrycode="USSR-LVA" if countryname=="Latvia"
	replace countrycode="USSR-MDA" if countryname=="Moldova"
	replace countrycode="CSFR" if countryname=="Czech Republic"
	replace countrycode="CSFR" if countryname=="Slovak Republic"
	replace countrycode="FYUG-MKD" if countryname=="Macedonia, FYR"
	replace countrycode="FYUG-YUG" if countryname=="Montenegro"
	replace countrycode="FYUG-YUG" if countryname=="Serbia"
	replace countrycode="KOREA-NO" if countryname=="Korea, Dem. Rep."
	replace countrycode="ROU" if countryname=="Romania"
	replace countrycode="USSR-RUS" if countryname=="Russian Federation"
	replace countrycode="FYUG-SVN" if countryname=="Slovenia"
	replace countrycode="USSR-TJK" if countryname=="Tajikistan"
	replace countrycode="USSR-TKM" if countryname=="Turkmenistan"
	replace countrycode="TLS" if countryname=="Timor-Leste"
	replace countrycode="USSR-UKR" if countryname=="Ukraine"
	replace countrycode="USSR-UZB" if countryname=="Uzbekistan"
	replace countrycode="COD" if countryname=="Congo, Dem. Rep."
	replace countrycode="FYUG-XXK" if countryname=="Kosovo"

**produce and save origin GDP for 2000 2005 2010
	collapse gdp1960- gdp2010, by ( countrycode )
	keep countrycode gdp2000 gdp2005 gdp2010
	reshape long gdp, i(countrycode) j(year)
	sort countrycode year
	ren gdp gdp_origin
	ren countrycode iso_o
	save "$tmp/GDP_origin.dta", replace 

**produce and save destination GDP for 2000 2005 2010

	gen destination=0
	replace destination=1 if iso_o=="AUS" | iso_o=="AUT" | iso_o=="BEL" | iso_o=="CAN" | iso_o=="CHE" | iso_o=="CHL" | iso_o=="CSFR-CZE" | iso_o=="DEU" | iso_o=="DNK" | iso_o=="ESP" | iso_o=="FIN" | iso_o=="FRA" | iso_o=="GBR" | iso_o=="GRC" | iso_o=="HUN" | iso_o=="IRL" | iso_o=="ISL" | iso_o=="ISR" | iso_o=="ITA" | iso_o=="JPN" | iso_o=="LUX" | iso_o=="MEX" | iso_o=="NLD" | iso_o=="NOR" | iso_o=="NZL" | iso_o=="POL" | iso_o=="PRT" | iso_o=="CSFR" | iso_o=="SWE" | iso_o=="TUR" | iso_o=="USA" 
	keep if destination==1
	drop des
	ren gdp_origin gdp_des
	ren iso_o iso_d
	save "$tmp/GDP_des.dta", replace

***Create GDP/K using WDI each birth cohort at 18 for origin and destination. Since we have 10-year age interval, I use the midpoint. EX, treating cohort 1946-1955 as 1950, and therefore use GDP in 1968 to measure variable GDP18 
*save output as "GDP_18origin.dta" and "GDP_18des.dta", respectively.  
*I use GDP in year 1960 for 18GDP for cohort 1336-1945, since 1960 is the eariest year when GDP values are observed in WDI

	use "$raw/WDI15.dta", clear

	replace countrycode="AND" if countryname=="Andorra"
	replace countrycode="USSR-ARM" if countryname=="Armenia"
	replace countrycode="USSR-AZE" if countryname=="Azerbaijan"
	replace countrycode="FYUG-BIH" if countryname=="Bosnia and Herzegovina"
	replace countrycode="USSR-BLR" if countryname=="Belarus"
	replace countrycode="USSR-EST" if countryname=="Estonia"
	replace countrycode="USSR-GEO" if countryname=="Georgia"
	replace countrycode="FYUG-HRV" if countryname=="Croatia"
	replace countrycode="USSR-KAZ" if countryname=="Kazakhstan"
	replace countrycode="USSR-KGZ" if countryname=="Kyrgyz Republic"
	replace countrycode="KOREA-SO" if countryname=="Korea, Rep."
	replace countrycode="USSR-LTU" if countryname=="Lithuania"
	replace countrycode="USSR-LVA" if countryname=="Latvia"
	replace countrycode="USSR-MDA" if countryname=="Moldova"
	replace countrycode="CSFR" if countryname=="Czech Republic"
	replace countrycode="CSFR" if countryname=="Slovak Republic"
	replace countrycode="FYUG-MKD" if countryname=="Macedonia, FYR"

	replace countrycode="FYUG-YUG" if countryname=="Montenegro"
	replace countrycode="FYUG-YUG" if countryname=="Serbia"
	replace countrycode="KOREA-NO" if countryname=="Korea, Dem. Rep."
	replace countrycode="ROU" if countryname=="Romania"
	replace countrycode="USSR-RUS" if countryname=="Russian Federation"
	replace countrycode="FYUG-SVN" if countryname=="Slovenia"
	replace countrycode="USSR-TJK" if countryname=="Tajikistan"
	replace countrycode="USSR-TKM" if countryname=="Turkmenistan"
	replace countrycode="TLS" if countryname=="Timor-Leste"
	replace countrycode="USSR-UKR" if countryname=="Ukraine"
	replace countrycode="USSR-UZB" if countryname=="Uzbekistan"
	replace countrycode="COD" if countryname=="Congo, Dem. Rep."
	replace countrycode="FYUG-XXK" if countryname=="Kosovo"

	collapse gdp1960- gdp2010, by ( countrycode )
	keep countrycode gdp1960 gdp1965 gdp1975 gdp1985 gdp1995 gdp2005
	reshape long gdp, i(countrycode) j(year)

	gen birth="1936-1945" if year==1960
	replace birth="1946-1955" if year==1965
	replace birth="1956-1965" if year==1975
	replace birth="1966-1975" if year==1985
	replace birth="1976-1985" if year==1995
	replace birth="1986-1995" if year==2005

**produce and save origin GDP for each cohort at 18
	ren gdp gdp_15origin
	sort countrycode birth
	drop year
	ren countrycode iso_o
	save "$tmp/GDP_15origin.dta", replace 

**produce and save destination GDP for each cohort at 18
	gen destination=0
	replace destination=1 if iso_o=="AUS" | iso_o=="AUT" | iso_o=="BEL" | iso_o=="CAN" | iso_o=="CHE" | iso_o=="CHL" | iso_o=="CSFR-CZE" | iso_o=="DEU" | iso_o=="DNK" | iso_o=="ESP" | iso_o=="FIN" | iso_o=="FRA" | iso_o=="GBR" | iso_o=="GRC" | iso_o=="HUN" | iso_o=="IRL" | iso_o=="ISL" | iso_o=="ISR" | iso_o=="ITA" | iso_o=="JPN" | iso_o=="LUX" | iso_o=="MEX" | iso_o=="NLD" | iso_o=="NOR" | iso_o=="NZL" | iso_o=="POL" | iso_o=="PRT" | iso_o=="CSFR" | iso_o=="SWE" | iso_o=="TUR" | iso_o=="USA" 
	keep if destination==1
	drop des
	ren gdp_15origin gdp_15des
	ren iso_o iso_d
	save "$tmp/GDP_15des.dta", replace

************Merge WDI data with DIOC-pop.dta
	use "$tmp/DIOC-pop.dta", clear
	set more off
	merge m:1 iso_o year using "$tmp/GDP_origin.dta"
	tab iso_o if _m==2
	drop _m
	merge m:1 iso_d year using "$tmp/GDP_des.dta"
	tab iso_d if _m==2
	drop _m
	merge m:1 iso_o birth using "$tmp/GDP_15origin.dta"
	tab iso_o if _m==2
	drop _m
	merge m:1 iso_d birth using "$tmp/GDP_15des.dta"
	tab iso_d if _m==2
	keep if _m==3
	drop _m

	save "$tmp/DIOC-POP-GDP.dta", replace

***********************************************************************************************************************************************************************************************************
***********************************************************************************************************************************************************************************************************

	use "$raw/dist_cepii.dta", clear

** Change the countrycode of cepii data to match DIOC country code
* for iso_o
	replace iso_o="FYUG-BIH" if iso_o=="BIH"
	replace iso_o="USSR-BLR" if iso_o=="BLR"
	replace iso_o="USSR-LVA" if iso_o=="LVA"
	replace iso_o="USSR-MDA" if iso_o=="MDA"
	replace iso_o="USSR-TJK" if iso_o=="TJK"
	replace iso_o="USSR-LTU" if iso_o=="LTU"
	replace iso_o="KOREA-SO" if iso_o=="KOR"
	replace iso_d="KOREA-NO" if iso_d=="PRK"
	replace iso_o="FYUG-HRV" if iso_o=="HRV"
	replace iso_o="USSR-GEO" if iso_o=="GEO"
	replace iso_o="USSR-TKM" if iso_o=="TKM"
	replace iso_o="ROU" if iso_o=="ROM"
	replace iso_o="CSFR" if iso_o=="CZE"
	replace iso_o="USSR-RUS" if iso_o=="RUS"
	replace iso_o="USSR-ARM" if iso_o=="ARM"
	replace iso_o="USSR-AZE" if iso_o=="AZE"
	replace iso_o="USSR-RWA" if iso_o=="RWA"
	replace iso_o="CSFR" if iso_o=="SVK"
	replace iso_o="USSR-KGZ" if iso_o=="KGZ"
	replace iso_o="USSR-UZB" if iso_o=="UZB"
	replace iso_o="USSR-UKR" if iso_o=="UKR"
	replace iso_o="FYUG-MKD" if iso_o=="MKD"
	replace iso_o="FYUG-SVN" if iso_o=="SVN"
	replace iso_o="FYUG-YUG" if iso_o=="YUG"
	replace iso_o="FYUG-YUG" if iso_o=="SRB"
	replace iso_o="FYUG-YUG" if iso_o=="MNE"
	replace iso_o="USSR-KAZ" if iso_o=="KAZ"
	replace iso_o="USSR-EST" if iso_o=="EST"
	replace iso_o="COD" if iso_o=="ZAR"

	* for iso_d
	replace iso_d="FYUG-BIH" if iso_d=="BIH"
	replace iso_d="USSR-BLR" if iso_d=="BLR"
	replace iso_d="USSR-LVA" if iso_d=="LVA"
	replace iso_d="USSR-MDA" if iso_d=="MDA"
	replace iso_d="USSR-TJK" if iso_d=="TJK"
	replace iso_d="USSR-LTU" if iso_d=="LTU"
	replace iso_d="KOREA-SO" if iso_d=="KOR"
	replace iso_d="KOREA-NO" if iso_d=="PRK"
	replace iso_d="FYUG-HRV" if iso_d=="HRV"
	replace iso_d="USSR-GEO" if iso_d=="GEO"
	replace iso_d="USSR-TKM" if iso_d=="TKM"
	replace iso_d="ROU" if iso_d=="ROM"
	replace iso_d="CSFR" if iso_d=="CZE"
	replace iso_d="USSR-RUS" if iso_d=="RUS"
	replace iso_d="USSR-ARM" if iso_d=="ARM"
	replace iso_d="USSR-AZE" if iso_d=="AZE"
	replace iso_d="CSFR" if iso_d=="SVK"
	replace iso_d="USSR-KGZ" if iso_d=="KGZ"
	replace iso_d="USSR-UZB" if iso_d=="UZB"
	replace iso_d="USSR-UKR" if iso_d=="UKR"
	replace iso_d="FYUG-MKD" if iso_d=="MKD"
	replace iso_d="FYUG-YUG" if iso_d=="YUG"
	replace iso_d="FYUG-YUG" if iso_d=="SRB"
	replace iso_d="FYUG-YUG" if iso_d=="MNE"
	replace iso_d="USSR-KAZ" if iso_d=="KAZ"
	replace iso_d="USSR-EST" if iso_d=="EST"
	replace iso_d="COD" if iso_d=="ZAR"

	collapse (max) contig comlang_off comlang_ethno colony comcol curcol col45 smctry dist distcap distw distwces,  by ( iso_o iso_d )

	save "$tmp/dist.dta", replace

***Merge dist.dta with DIOC-POP-GDP.dta and save it as the final output called DIOC-POP-GDP-DIST.dta
	use "$tmp/DIOC-POP-GDP.dta", clear
	merge m:1 iso_o iso_d using "$tmp/dist.dta"

	tab iso_o if _m==1
	keep if _m==3
	drop _m

	replace number=floor(number) if act==0
	sort iso_o iso_d birth sex year


***Indicating whether birth cohort is first observed at 0-9 year old, 1 for yes and 0 otherwise
	gen base=1
	replace base=0 if birth=="1936-1945" 

***Relative labor supply
	gen relsp= origin_pop/ des_pop

***Migration rate

	foreach x in des_pop des_base_pop des_base_pop_lag10 des_base_pop_lag20 origin_pop origin_base_pop origin_base_pop_lag10 origin_base_pop_lag20 {
		replace `x'=1000*`x'
		}

	gen mrat=number/origin_base_pop

	sort year
	by year: sum mrat
	list iso_o iso_d birth year sex mrat if mrat>1 & mrat<2

	drop if year==2005
	sort iso_o iso_d sex year birth

	label variable iso_o "origin"
	label variable iso_d "destination"
	label variable birth "10-year birth cohort"
	label variable year "year"
	label variable sex "sex"
	label variable number "migration count"
	label variable country "origin country"
	label variable region "region"
	label variable des_pop "destination pop at each year"
	label variable origin_pop "origin pop at each year"
	label variable des_base_pop "destination pop first observed"
	label variable origin_base_pop "origin pop first observed"
	label variable origin_base_pop_lag10 "10-year older origin pop first observed"
	label variable origin_base_pop_lag20 "20-year older origin pop first observed"
	label variable des_base_pop_lag10 "10-year older des pop first observed"
	label variable des_base_pop_lag20 "20-year older des pop first observed"
	label variable actual "0 for interpolated data"
	label variable gdp_origin "GDP/K at origin"
	label variable gdp_des "GDP/K at destination"
	label variable gdp_15origin "origin GDP/K at age 15"
	label variable gdp_15des "destination GDP/K at age 15"
	label variable contig "1 for contiguity"
	label variable comlang_off " 1 for common official of primary language"
	label variable comlang_ethno "1 if a language is spoken by at least 9% of the population in both countries"
	label variable colony "1 for pairs ever in colonial relationship"
	label variable comcol "1 for common colonizer post 1945"
	label variable curcol " 1 for pairs currently in colonial relationship"
	label variable col45 "1 for pairs in colonial relationship post 1945"
	label variable smctry " 1 if countries were or are the same country"
	label variable dist "simple distance (most populated cities, km)"
	label variable distcap "simple distance between capitals (capitals, km)"
	label variable distw "weighted distance (pop-wt, km)"
	label variable distwces "weighted distance (pop-wt, km) CES distances with theta=-1"
	label variable base "1 if birth cohort is first observed at 0-9"
	label variable mrat "migration rate"
	label variable relsp "pop ratio of des/origin"

	saveold "$tmp/DIOC-POP-GDP-DIST_15.dta", replace version(12)


/******************************************************************************/
/*								FORECAST MERGE: 2020-2050  			   		  */
/******************************************************************************/

*** Create base cohort for 2016-2025 and 2026-2035 from ZERO-MIGRATION spreadsheet

	use "$raw/2020-2100.dta", clear
	keep if year<=2035
	drop if year==2015

	gen birth="2016-2025" if year==2020 | year==2025
	replace birth="2026-2035" if year==2030 | year==2035

	collapse (rawsum)pop, by (country birth sex)

	save "$tmp/2016-2035.dta", replace

*** Create base cohort for 1956-1965 up to 2006-2015 from estimate spreadsheet

	use "$raw/unpop.dta", clear
	keep country year age04 sex
	keep if year>=1960
	gen birth="1956-1965" if year==1960 | year==1965
	replace birth="1966-1975" if year==1970 | year==1975
	replace birth="1976-1985" if year==1980 | year==1985
	replace birth="1986-1995" if year==1990 | year==1995
	replace birth="1996-2005" if year==2000 | year==2005
	replace birth="2006-2015" if year==2010 | year==2015

	ren age04 pop
	collapse (rawsum)pop, by (country birth sex)

	append using "$tmp/2016-2035.dta"
	sort country birth sex

	merge m:1 country using "$raw/code.dta"
	drop _m

	sort country sex birth 
	gen base_pop_lag10=pop[_n-1] if  country==country[_n-1] & sex==sex[_n-1] 
	drop if iso==""
	ren iso iso_o
	collapse (firstnm)country (rawsum) pop (rawsum) base_pop_lag10 , by ( iso_o sex birth)

	save "$tmp/origin_pop1956-2035", replace

	gen destination=0
	ren iso countrycode
	replace destination=1 if countrycode=="AUS" | countrycode=="AUT" | countrycode=="BEL" | countrycode=="CAN" | countrycode=="CHE" | countrycode=="CHL" | countrycode=="CSFR" | countrycode=="CSFR-SVK" | countrycode=="DEU" | countrycode=="DNK" | countrycode=="ESP" | countrycode=="FIN" | countrycode=="FRA" | countrycode=="FYUG-SVN" | countrycode=="GBR" | countrycode=="GRC" | countrycode=="HUN" | countrycode=="IRL" | countrycode=="ISL" | countrycode=="ISR" | countrycode=="ITA" | countrycode=="JPN" | countrycode=="LUX" | countrycode=="MEX" | countrycode=="NLD" | countrycode=="NOR" | countrycode=="NZL" | countrycode=="POL" | countrycode=="PRT" | countrycode=="SVK" | countrycode=="SWE" | countrycode=="TUR" | countrycode=="USA" | countrycode=="USSR-EST"
	drop if countrycode==""
	keep if des==1
	drop country
	ren countrycode iso
	ren pop des_base_pop
	ren base_pop_lag10 des_base_pop_lag10
	ren iso iso_d
	drop dest
	save "$tmp/des_pop1956-2035", replace

	collapse (firstnm)sex, by (iso_d)
	drop sex
	gen id=_n
	save "$tmp/dest.dta", replace

	use "$tmp/origin_pop1956-2035.dta", clear
	ren pop origin_base_pop
	ren base_pop_lag10 origin_base_pop_lag10
	save "$tmp/origin_pop1956-2035", replace


** Simulating origin-des-sex-cohort-year table

	collapse (firstnm)sex, by (iso_o)
	drop sex
	expand 31
	sort iso_o
	by iso_o: gen id=_n

	merge m:1 id using "$tmp/dest.dta"
	drop id _m

	expand 4 
	sort iso_o iso_d
	by iso_o iso_d: gen a=_n
	gen year=2010+10*a
	drop a

	expand 5 
	sort iso_o iso_d year
	by iso_o iso_d year: gen a=_n

	gen cohort="1956-1965" if a==1 & year==2020
	replace cohort="1966-1975" if a==2 & year==2020
	replace cohort="1976-1985" if a==3 & year==2020
	replace cohort="1986-1995" if a==4 & year==2020
	replace cohort="1996-2005" if a==5 & year==2020

	replace cohort="1966-1975" if a==1 & year==2030
	replace cohort="1976-1985" if a==2 & year==2030
	replace cohort="1986-1995" if a==3 & year==2030
	replace cohort="1996-2005" if a==4 & year==2030
	replace cohort="2006-2015" if a==5 & year==2030

	replace cohort="1976-1985" if a==1 & year==2040
	replace cohort="1986-1995" if a==2 & year==2040
	replace cohort="1996-2005" if a==3 & year==2040
	replace cohort="2006-2015" if a==4 & year==2040
	replace cohort="2016-2025" if a==5 & year==2040

	replace cohort="1986-1995" if a==1 & year==2050
	replace cohort="1996-2005" if a==2 & year==2050
	replace cohort="2006-2015" if a==3 & year==2050
	replace cohort="2016-2025" if a==4 & year==2050
	replace cohort="2026-2035" if a==5 & year==2050
	drop a

	expand 2 
	sort iso_o iso_d year cohort
	by iso_o iso_d year cohort: gen a=_n 
	gen sex="male" if a==1
	replace sex="female" if a==2
	ren cohort birth

	merge m:1 iso_o sex birth using "$tmp/origin_pop1956-2035.dta"
	drop _m a
	merge m:1 iso_d sex birth using "$tmp/des_pop1956-2035.dta"
	sum origin_base_pop des_base_pop
	replace origin_base_pop_lag10=. if origin_base_pop_lag10==0
	replace des_base_pop_lag10=. if des_base_pop_lag10==0

	sort iso_o iso_d year birth sex
	drop _m

	save "$tmp/pop2020-2050.dta", replace


**Adding distance variables

	use "$raw/dist_cepii.dta", clear

** Change the countrycode of cepii data to match DIOC country code
	* for iso_o
	replace iso_o="FYUG-BIH" if iso_o=="BIH"
	replace iso_o="USSR-BLR" if iso_o=="BLR"
	replace iso_o="USSR-LVA" if iso_o=="LVA"
	replace iso_o="USSR-MDA" if iso_o=="MDA"
	replace iso_o="USSR-TJK" if iso_o=="TJK"
	replace iso_o="USSR-LTU" if iso_o=="LTU"
	replace iso_o="KOREA-SO" if iso_o=="KOR"
	replace iso_o="FYUG-HRV" if iso_o=="HRV"
	replace iso_o="USSR-GEO" if iso_o=="GEO"
	replace iso_o="USSR-TKM" if iso_o=="TKM"
	replace iso_o="ROU" if iso_o=="ROM"
	replace iso_o="CSFR" if iso_o=="CZE"
	replace iso_o="USSR-RUS" if iso_o=="RUS"
	replace iso_o="USSR-ARM" if iso_o=="ARM"
	replace iso_o="USSR-AZE" if iso_o=="AZE"
	replace iso_o="USSR-RWA" if iso_o=="RWA"
	replace iso_o="CSFR" if iso_o=="SVK"
	replace iso_o="USSR-KGZ" if iso_o=="KGZ"
	replace iso_o="USSR-UZB" if iso_o=="UZB"
	replace iso_o="USSR-UKR" if iso_o=="UKR"
	replace iso_o="FYUG-MKD" if iso_o=="MKD"
	replace iso_o="FYUG-YUG" if iso_o=="YUG"
	replace iso_o="FYUG-YUG" if iso_o=="SRB"
	replace iso_o="FYUG-YUG" if iso_o=="MNE"
	replace iso_o="USSR-KAZ" if iso_o=="KAZ"
	replace iso_o="USSR-EST" if iso_o=="EST"
	replace iso_o="COD" if iso_o=="ZAR"

	* for iso_o
	replace iso_d="FYUG-BIH" if iso_d=="BIH"
	replace iso_d="USSR-BLR" if iso_d=="BLR"
	replace iso_d="USSR-LVA" if iso_d=="LVA"
	replace iso_d="USSR-MDA" if iso_d=="MDA"
	replace iso_d="USSR-TJK" if iso_d=="TJK"
	replace iso_d="USSR-LTU" if iso_d=="LTU"
	replace iso_d="KOREA-SO" if iso_d=="KOR"
	replace iso_d="FYUG-HRV" if iso_d=="HRV"
	replace iso_d="USSR-GEO" if iso_d=="GEO"
	replace iso_d="USSR-TKM" if iso_d=="TKM"
	replace iso_d="ROU" if iso_d=="ROM"
	replace iso_d="CSFR" if iso_d=="CZE"
	replace iso_d="USSR-RUS" if iso_d=="RUS"
	replace iso_d="USSR-ARM" if iso_d=="ARM"
	replace iso_d="USSR-AZE" if iso_d=="AZE"
	replace iso_d="CSFR" if iso_d=="SVK"
	replace iso_d="USSR-KGZ" if iso_d=="KGZ"
	replace iso_d="USSR-UZB" if iso_d=="UZB"
	replace iso_d="USSR-UKR" if iso_d=="UKR"
	replace iso_d="FYUG-MKD" if iso_d=="MKD"
	replace iso_d="FYUG-YUG" if iso_d=="YUG"
	replace iso_d="FYUG-YUG" if iso_d=="SRB"
	replace iso_d="FYUG-YUG" if iso_d=="MNE"
	replace iso_d="USSR-KAZ" if iso_d=="KAZ"
	replace iso_d="USSR-EST" if iso_d=="EST"
	replace iso_d="COD" if iso_d=="ZAR"

	collapse (max) contig comlang_off comlang_ethno colony comcol curcol col45 smctry dist distcap distw distwces,  by ( iso_o iso_d )
	
	save "$tmp/dist.dta", replace

	use "$tmp/pop2020-2050.dta", clear
	merge m:1 iso_o iso_d using "$tmp/dist.dta"

	tab iso_o if _m==1
	drop if _m==2
	drop _m

	save "$tmp/pop-dist.dta", replace


***merge IMF dataset

	use "$raw/GPK15.dta", clear

	merge m:1 country using "$raw/code.dta"

	replace iso="BHS" if country=="Bahamas, The"
	replace iso="BOL" if country=="Bolivia"
	replace iso="HKG" if country=="Hong Kong SAR"
	replace iso="COG" if country=="Congo, Republic of "
	replace iso="CIV" if country=="Côte d'Ivoire"
	replace iso="KOREA-NO" if country=="Korea, Dem. People's Rep. of"
	replace iso="COD" if country=="Congo, Dem. Rep. of the"
	replace iso="GMB" if country=="Gambia, The"
	replace iso="IRN" if country=="Iran"
	replace iso="USSR-KGZ" if country=="Kyrgyz Republic"
	replace iso="LAO" if country=="Lao P.D.R."
	replace iso="FSM" if country=="Micronesia, Fed. States of"
	replace iso="KOREA-SO" if country=="Korea, Republic of"
	replace iso="USSR-MDA" if country=="Moldova"
	replace iso="STP" if country=="São Tomé and Príncipe"
	replace iso="CSFR" if country=="Slovak Republic"
	replace iso="SSD" if country=="South Sudan, Republic of"
	replace iso="SYR" if country=="Syria"
	replace iso="TZA" if country=="Tanzania"
	replace iso="VIR" if country=="United States Virgin Islands "
	replace iso="USA" if country=="United States"
	replace iso="VNM" if country=="Vietnam"
	replace iso="VEN" if country=="Venezuela"
	replace iso="CHN" if country=="China, People's Republic of"

	drop if _m==2
	drop if iso==""
	drop _m
	collapse (firstnm)country gdp2015- gdp2020, by (iso)
	save "$tmp/IMF_gdp.dta", replace

	use "$raw/WDI15.dta", clear
	replace countrycode="AND" if countryname=="Andorra"
	replace countrycode="USSR-ARM" if countryname=="Armenia"
	replace countrycode="USSR-AZE" if countryname=="Azerbaijan"
	replace countrycode="FYUG-BIH" if countryname=="Bosnia and Herzegovina"
	replace countrycode="USSR-BLR" if countryname=="Belarus"
	replace countrycode="USSR-EST" if countryname=="Estonia"
	replace countrycode="USSR-GEO" if countryname=="Georgia"
	replace countrycode="FYUG-HRV" if countryname=="Croatia"
	replace countrycode="USSR-KAZ" if countryname=="Kazakhstan"
	replace countrycode="USSR-KGZ" if countryname=="Kyrgyz Republic"
	replace countrycode="KOREA-SO" if countryname=="Korea, Rep."
	replace countrycode="KOREA-NO" if countryname=="Korea, Dem. Rep."
	replace countrycode="USSR-LTU" if countryname=="Lithuania"
	replace countrycode="USSR-LVA" if countryname=="Latvia"
	replace countrycode="USSR-MDA" if countryname=="Moldova"
	replace countrycode="CSFR" if countryname=="Czech Republic"
	replace countrycode="CSFR" if countryname=="Slovak Republic"
	replace countrycode="FYUG-MKD" if countryname=="Macedonia, FYR"

	replace countrycode="FYUG-YUG" if countryname=="Montenegro"
	replace countrycode="FYUG-YUG" if countryname=="Serbia"
	replace countrycode="KOREA-NO" if countryname=="Korea, Dem. Rep."
	replace countrycode="ROU" if countryname=="Romania"
	replace countrycode="USSR-RUS" if countryname=="Russian Federation"
	replace countrycode="FYUG-SVN" if countryname=="Slovenia"
	replace countrycode="USSR-TJK" if countryname=="Tajikistan"
	replace countrycode="USSR-TKM" if countryname=="Turkmenistan"
	replace countrycode="TLS" if countryname=="Timor-Leste"
	replace countrycode="USSR-UKR" if countryname=="Ukraine"
	replace countrycode="USSR-UZB" if countryname=="Uzbekistan"
	replace countrycode="COD" if countryname=="Congo, Dem. Rep."
	replace countrycode="FYUG-XXK" if countryname=="Kosovo"
	ren countryname country
	ren countrycode iso
	collapse (firstnm)country gdp1975 gdp1985 gdp1995 gdp2005 , by (iso)
	merge 1:1 iso using "$tmp/IMF_gdp.dta"
	save "$tmp/IMF_gdp.dta", replace

** Extracting origin gdp for 2020-2050
	gen gr1=(gdp2019-gdp2018)/gdp2018
	gen gr2=(gdp2020-gdp2019)/gdp2019
	gen avgr=(gr1+gr2)/2

	gen gdp2030=gdp2020*(1+avgr)^10
	gen gdp2040=gdp2020*(1+avgr)^20
	gen gdp2050=gdp2020*(1+avgr)^30

	keep coun gdp2020 gdp2030 gdp2040 gdp2050 iso
	ren iso iso_o
	reshape long gdp, i(iso_o) j(year)
	ren gdp gdp_origin
	save "$tmp/gdp2020-2050origin.dta", replace

** Extracting des gdp for 2020-2050

	gen destination=0
	ren iso countrycode
	replace destination=1 if countrycode=="AUS" | countrycode=="AUT" | countrycode=="BEL" | countrycode=="CAN" | countrycode=="CHE" | countrycode=="CHL" | countrycode=="CSFR" | countrycode=="CSFR-SVK" | countrycode=="DEU" | countrycode=="DNK" | countrycode=="ESP" | countrycode=="FIN" | countrycode=="FRA" | countrycode=="FYUG-SVN" | countrycode=="GBR" | countrycode=="GRC" | countrycode=="HUN" | countrycode=="IRL" | countrycode=="ISL" | countrycode=="ISR" | countrycode=="ITA" | countrycode=="JPN" | countrycode=="LUX" | countrycode=="MEX" | countrycode=="NLD" | countrycode=="NOR" | countrycode=="NZL" | countrycode=="POL" | countrycode=="PRT" | countrycode=="SVK" | countrycode=="SWE" | countrycode=="TUR" | countrycode=="USA" | countrycode=="USSR-EST"
	drop if countrycode==""
	keep if des==1
	ren countrycode iso_d
	drop des
	ren gdp_origin gdp_des
	save "$tmp/gdp2020-2050des.dta", replace


** Extracting origin gdp when 18 years old

	use "$tmp/IMF_gdp", clear

	gen gr1=(gdp2019-gdp2018)/gdp2018
	gen gr2=(gdp2020-gdp2019)/gdp2019
	gen avgr=(gr1+gr2)/2

	gen gdp2025=gdp2020*(1+avgr)^5
	gen gdp2035=gdp2020*(1+avgr)^15
	gen gdp2045=gdp2020*(1+avgr)^25

	keep iso country gdp1975 gdp1985 gdp1995 gdp2005 gdp2015 gdp2025 gdp2035 gdp2045 

	reshape long gdp, i(iso) j(year)

	gen birth="1956-1965" if year==1975
	replace birth="1966-1975" if year==1985
	replace birth="1976-1985" if year==1995
	replace birth="1986-1995" if year==2005
	replace birth="1996-2005" if year==2015
	replace birth="2006-2015" if year==2025
	replace birth="2016-2025" if year==2035
	replace birth="2026-2035" if year==2045

	drop year country
	ren gdp gdp_15origin
	ren iso iso_o
	sort iso_o birth

	save "$tmp/gdp15origin.dta", replace

** Extracting des gdp when 18 years old

	gen destination=0
	ren iso countrycode
	replace destination=1 if countrycode=="AUS" | countrycode=="AUT" | countrycode=="BEL" | countrycode=="CAN" | countrycode=="CHE" | countrycode=="CHL" | countrycode=="CSFR" | countrycode=="CSFR-SVK" | countrycode=="DEU" | countrycode=="DNK" | countrycode=="ESP" | countrycode=="FIN" | countrycode=="FRA" | countrycode=="FYUG-SVN" | countrycode=="GBR" | countrycode=="GRC" | countrycode=="HUN" | countrycode=="IRL" | countrycode=="ISL" | countrycode=="ISR" | countrycode=="ITA" | countrycode=="JPN" | countrycode=="LUX" | countrycode=="MEX" | countrycode=="NLD" | countrycode=="NOR" | countrycode=="NZL" | countrycode=="POL" | countrycode=="PRT" | countrycode=="SVK" | countrycode=="SWE" | countrycode=="TUR" | countrycode=="USA" | countrycode=="USSR-EST"
	drop if countrycode==""
	keep if des==1
	ren countrycode iso_d
	drop des
	ren gdp_15origin gdp_15des
	save "$tmp/gdp15des.dta", replace

	use "$tmp/pop-dist.dta", clear
	merge m:1 iso_o year using "$tmp/gdp2020-2050origin.dta"
	tab iso_o if _m==2
	drop _m
	merge m:1 iso_d year using "$tmp/gdp2020-2050des.dta"
	tab iso_d if _m==2
	drop _m
	merge m:1 iso_o birth using "$tmp/gdp15origin.dta"
	tab iso_o if _m==2
	drop _m
	merge m:1 iso_d birth using "$tmp/gdp15des.dta"
	tab iso_d if _m==2
	keep if _m==3

	drop _m
	sort iso_o iso_d year birth sex
	drop if iso_o==""

	saveold "$tmp/pop-dist-gpd2020-2050", replace version(12)

* Append to UN data	
	append using "$tmp/DIOC-POP-GDP-DIST_15.dta" 
	saveold "$fin/output$date.dta", replace version(12)
	
/******************************************************************************/
/*								DATA CLEANING				  				  */
/******************************************************************************/	
	

/* Forecast data which has all cohort sizes divided by 1000:*/
	#delimit;
	use "$fin/output$date.dta", clear;

	foreach x in origin_base_pop origin_base_pop_lag10 des_base_pop des_base_pop_lag10 {;
		replace `x' = 	`x'*1000 if year>2010;
		};


	rename birth birth_cohort;
	gen migperc = mrat*100;
	order iso_o iso_d birth_cohort sex year;

	sort iso_o iso_d birth_cohort sex year;
	egen bcohort_id = group(iso_o iso_d birth_cohort sex);
	egen dyad_id = group(iso_o iso_d);
	gen dmigperc = migperc - migperc[_n-1] if bcohort_id == bcohort_id[_n-1] & iso_o == iso_o[_n-1] & iso_d == iso_d[_n-1] & sex==sex[_n-1] ;
	label var bcohort_id "Identifier for the dyad/cohort/gender group, common across survey years";

/*Writing the one migration change onto all observations so regressions can be run in 2000 only, using the correct cohort growth lags.:*/
	#delimit;
	egen dmigpercm = mean(dmigperc), by(bcohort_id);
	encode iso_o, gen(id_o);
	encode iso_d, gen(id_d);
	encode birth_cohort, gen(id_bcohort);
	gen female = (sex=="female");

/*birth cohort size ratios:*/
	#delimit;
	gen brat = origin_base_pop/des_base_pop;
	gen lbrat = ln(brat);
	gen brat_lag10 = origin_base_pop_lag10/des_base_pop_lag10;
	gen brat_lag20 = origin_base_pop_lag20/des_base_pop_lag20;
	gen lbrat_lag10 = ln(brat_lag10);
	gen lbrat_lag20 = ln(brat_lag20);
	gen lbrat_dif10 = lbrat - lbrat_lag10;
	gen lbrat_dif20 = lbrat - lbrat_lag20;
	gen brat_chg10 = brat - brat_lag10;
	gen brat_chg20 = brat - brat_lag20;
	gen lbrat_chg10 = ln(brat_chg10);
	gen lbrat_chg20 = ln(brat_chg20);
	gen pbrat_chg10 = (brat_chg10/brat_lag10);
	gen pbrat_chg20 = (brat_chg20/brat_lag20);

/*log GDP ratios:*/
	#delimit;
	gen gdprat = gdp_origin/gdp_des;
	gen lgdprat = ln(gdprat);
	gen gdp15rat =  gdp_15origin/gdp_15des;
	gen lgdp15rat = ln(gdp15rat);
	gen ldist = ln(dist);
	gen lmigperc = ln(migperc);

	egen mig_count = count(migperc), by(bcohort_id);

/*dropping out cohorts that never have migration observed:*/
	*drop if mig_count==0;
	egen des_mig_max = max(mig_count), by(iso_d);

/*destinations with only one migration count:*/
	tab iso_d if des_mig_max==1;

	egen orig_mig_max = max(mig_count), by(iso_o);

/*defining the panel sample that has at least two migration observations per cohort:*/
	gen sample_PANEL = (mig_count==2);

/*defining the 'stable' sample that is panel and also has all the covariates:*/
	#delimit;
	gen sample_COMPLETE = sample_PANEL;
	foreach x in $covars {;
		replace sample_COMPLETE = 0 if `x'==.;
		};
		

	gen birth_midpoint = 1940 if birth_cohort=="1936-1945";
	replace birth_midpoint = 1950 if birth_cohort=="1946-1955";
	replace birth_midpoint = 1960 if birth_cohort=="1956-1965";
	replace birth_midpoint = 1970 if birth_cohort=="1966-1975";
	replace birth_midpoint = 1980 if birth_cohort=="1976-1985";
	replace birth_midpoint = 1990 if birth_cohort=="1986-1995";
	replace birth_midpoint = 2000 if birth_cohort=="1996-2005";
	replace birth_midpoint = 2010 if birth_cohort=="2006-2015";
	replace birth_midpoint = 2020 if birth_cohort=="2016-2025";
	replace birth_midpoint = 2030 if birth_cohort=="2026-2035";

	gen age_midpoint = year - birth_midpoint;


/*Defining the older groups in 2000 on whom the high-migration kernels will be defined:*/
	#delimit;	
	gen old_yr2000 = (age_midpoint>=50 & age_midpoint!=. & year==2000);
	egen cut_lo = pctile(migperc) if old_yr2000==1, p(50);
	egen cut_med = pctile(migperc) if old_yr2000==1, p(80);
	egen cut_hi = pctile(migperc) if old_yr2000==1, p(95);

/*Defining older high-migration dyads in 2000, using cutpoints of .005%, .1%, and 1%:*/
	#delimit;
	gen mig_kernel_lo1= (old_yr2000==1 & migperc>=cut_lo & migperc!=.);
	gen mig_kernel_med1= (old_yr2000==1 & migperc>=cut_med & migperc!=.);
	gen mig_kernel_hi1= (old_yr2000==1 & migperc>=cut_hi & migperc!=.);

	foreach x in lo med hi {;
		egen mig_kernel_`x' = max(mig_kernel_`x'1), by(dyad);
		drop mig_kernel_`x'1;
		gen lbrat_kernel_`x' = lbrat * mig_kernel_`x';
		};


	egen origin_base_m = mean(origin_base_pop), by(dyad_id);

	drop if iso_o==iso_d;

	egen region2 = mode(region), by(iso_o);
	replace region = region2 if region=="";

/*These are the destinations that record migration only in 2010; we want to handle their predictions differently than the others:*/
	#delimit;
	gen m2010_only = (iso_d=="CHL" | iso_d=="DEU" | iso_d=="ISL" | iso_d=="ISR" | iso_d=="NLD");

/*These are the dyads that ever record a migration total; prediction not done for the rest of dyads:*/
	egen dyad_ever1 = count(number), by(dyad_id);
	gen dyad_ever = (dyad_ever1!=0);  drop dyad_ever1;

/*predicting migration numbers out through 2050, model that uses origin and destination FE but not dyad FE:*/	
	#delimit;
	set more off;
	foreach x in mig_kernel_lo mig_kernel_med mig_kernel_hi ldist contig colony comlang_ethno {;
		gen inter_`x' = lbrat_dif10 * `x';
		};
	reg dmigpercm mig_kernel_lo inter_mig_kernel_lo mig_kernel_med inter_mig_kernel_med mig_kernel_hi inter_mig_kernel_hi 
		ldist inter_ldist contig inter_contig colony inter_colony comlang_ethno inter_comlang_ethno lbrat_dif10 i.id_o i.id_d  i.age_midpoint i.female if sample_PANEL==1 & year==2000 [aw = origin_base_pop], cluster(bcohort_id);
		predict dmigpercm_hat;
	sort iso_d iso_o birth_cohort female year;

	/*first for the countries that record migperc non-missing in 2010:*/
	gen migperc_hat = (migperc[_n-1] + dmigpercm_hat) if (year==2020 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (year==2030 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (year==2040 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (year==2050 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);

	/*actual  values when observed:*/
	replace migperc_hat = migperc if (year==2000 | year==2010) & migperc!=.;

	/*then the 2000 prediction for the countries that have migration counts in 2010 only:*/
	replace migperc_hat = migperc[_n+1] - dmigpercm_hat if year==2000 & m2010_only==1;

	/*starting from 0 for the cohorts we first observe only in simulation:*/
	replace migperc_hat = dmigpercm_hat if age_midpoint==20 & migperc_hat==. & dyad_ever==1;
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (age_midpoint==30 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat==. & dyad_ever==1);
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (age_midpoint==40 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat==. & dyad_ever==1);
	replace migperc_hat = (migperc_hat[_n-1] + dmigpercm_hat) if (age_midpoint==50 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat==. & dyad_ever==1);

	/*calculating actual numbers of migrants based on the predictions:*/
	gen number_hat = (migperc_hat/100) * origin_base_pop;


/*predicting migration numbers out through 2050, model that includes gdp15 in the projections:*/	
	#delimit;
	set more off;
	reg dmigpercm lgdp15rat mig_kernel_lo inter_mig_kernel_lo mig_kernel_med inter_mig_kernel_med mig_kernel_hi inter_mig_kernel_hi 
	ldist inter_ldist contig inter_contig colony inter_colony comlang_ethno inter_comlang_ethno lbrat_dif10 i.id_o i.id_d  i.age_midpoint i.female if sample_PANEL==1 & year==2000 [aw = origin_base_pop], cluster(bcohort_id);
	predict dmigpercm_hat2;
	sort iso_d iso_o birth_cohort female year;

	/*first for the countries that record migperc non-missing in 2010:*/
	gen migperc_hat2 = (migperc[_n-1] + dmigpercm_hat2) if (year==2020 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat2 = (migperc_hat[_n-1] + dmigpercm_hat2) if (year==2030 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat2 = (migperc_hat[_n-1] + dmigpercm_hat2) if (year==2040 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	replace migperc_hat2 = (migperc_hat[_n-1] + dmigpercm_hat2) if (year==2050 & dyad_id==dyad_id[_n-1] & female==female[_n-1]);
	
	/*actual  values when observed:*/
	replace migperc_hat2 = migperc if (year==2000 | year==2010) & migperc!=.;
	
	/*then the 2000 prediction for the countries that have migration counts in 2010 only:*/
	replace migperc_hat2 = migperc[_n+1] - dmigpercm_hat2 if year==2000 & m2010_only==1;
	
	/*starting from 0 for the cohorts we first observe only in simulation:*/
	replace migperc_hat2 = dmigpercm_hat2 if age_midpoint==20 & migperc_hat2==. & dyad_ever==1;
	replace migperc_hat2 = (migperc_hat2[_n-1] + dmigpercm_hat2) if (age_midpoint==30 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat2==. & dyad_ever==1);
	replace migperc_hat2 = (migperc_hat2[_n-1] + dmigpercm_hat2) if (age_midpoint==40 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat2==. & dyad_ever==1);
	replace migperc_hat2 = (migperc_hat2[_n-1] + dmigpercm_hat2) if (age_midpoint==50 & dyad_id==dyad_id[_n-1] & female==female[_n-1] & migperc_hat2==. & dyad_ever==1);
	
	/*calculating actual numbers of migrants based on the predictions:*/
	gen number_hat2 = (migperc_hat2/100) * origin_base_pop;


/*Making an 'origin group' variable for the later graphs of destinations by origin:*/
	#delimit;
	gen origin_group = "India" if iso_o=="IND";
	replace origin_group = "China" if iso_o=="CHN";

	replace origin_group = "SSA" if region=="AFRI";
	foreach x in  Algeria Bahrain Djibouti Egypt  Iraq Israel Jordan Kuwait Lebanon Libya Malta Morocco Oman Qatar Tunisia Turkey Yemen {;
		replace origin_group = "MENA" if country=="`x'";
		};
	foreach x in IRN SAU SYR ARE {;
		replace origin_group = "MENA" if iso_o=="`x'";
		};
	replace origin_group = "Other" if origin_group=="";

	gen origin_group_USA = origin_group;
	replace origin_group_USA = "Mexico" if iso_o=="MEX";

	gen origin_group_EUR = origin_group;
	foreach x in Belarus Bulgaria Hungary Moldova Poland Romania Ukraine {;
		replace origin_group_EUR = "E_Europe" if country=="`x'";
		};
	foreach x in CZE FYUG-BIH FYUG-HRV FYUG-MKD FYUG-SVN FYUG-YUG USSR-EST USSR-LTU USSR-LVA USSR-MDA USSR-RUS USSR-UDR {;
		replace origin_group_EUR = "E_Europe" if country=="`x'";
		};
		
	gen origin_group_JAP = origin_group;
	replace origin_group_JAP = "Korea" if iso_o=="KOREA-NO";
	replace origin_group_JAP = "Korea" if iso_o=="KOREA-SO";

	gen origin_group_global = "Asia" if region=="ASIA";
	replace origin_group_global = "SSA" if origin_group=="SSA";
	replace origin_group_global = "MENA" if origin_group=="MENA";
	replace origin_group_global = "LAC" if region=="SCAC";	

	sort iso_d iso_o birth_cohort female year;

	#delimit;
	gen major_dest = 0;
	foreach x in USA JPN DEU GBR FRA ITA ESP CAN AUS {;
		replace major_dest=1 if iso_d=="`x'";
		};


	foreach x in lbrat_dif10 lgdp15rat {;
		egen `x'm = mean(`x') if sample_PANEL==1 & year==2000; 
		gen `x'dm = `x' - `x'm if sample_PANEL==1 & year==2000;
		};	
	

/* Save cleaned file for analysis */

	saveold "$fin/migration_JEP_data_$date", replace version(12)
	
